import java.awt.Color;
import java.awt.Dimension;
import java.awt.Graphics;

import javax.swing.JComponent;

/**
 *  A Java Swing component that draws a bull's eye
 *
 *  @author Nicholas R. Howe, modified by Sara Sheehan
 *  @version February 8, 2016
 */
public class JBullsEye extends JComponent {
	
	/** For serializing the class (ignore for now) */
	private static final long serialVersionUID = 1L;

	/** The diameter of the bull's eye */
    private int diameter;

    /** The colors of the bull's eye */
    private Color colorArray[];

    /**
     *  Creates a JBullseye of specified size.
     *  The default color is black.
     *
     *  @param r Specifies the radius of the circle
     */
    public JBullsEye(int r, Color[] colorArray) {
    		super(); // what constructor does this call?
    		this.diameter = 2*r;
    		this.colorArray = colorArray;
    }

    /** Accessor for radius */
    public int getRadius() {
    		return this.diameter/2;
    }

    /** Manipulator for radius */
    public void setRadius(int r) {
    		this.diameter = 2*r;
    }

    /** Accessor for color array */
    public Color[] getColorArray() {
    		return this.colorArray;
    }

    /** Manipulator for color array */
    public void setColors(Color[] newColorArray) {
    		this.colorArray = newColorArray;
    		repaint(); // where is this method defined?
    }

    /**
     *  Draws the circle in the graphics window
     *  @param g The graphics object to draw into
     */
    public void paintComponent(Graphics g) {
    		int numColors = this.colorArray.length;
    		for (int i = 0; i < numColors; i++) {
    			g.setColor(this.colorArray[i]); // change "paintbrush"
    			int ring = (this.diameter*(numColors-i))/numColors;
    			int start = (this.diameter-ring)/2;
    			g.fillOval(start,start,ring,ring);
    		}
    }

    /** Cycle the colors in the bull's eye */
    public void cycle() {
    		int numColors = this.colorArray.length;
    		Color firstColor = this.colorArray[0]; // save the outside color
    		
    		for (int i = 1; i < numColors; i++) {
    			this.colorArray[i-1] = this.colorArray[i];
    		}
    		
    		this.colorArray[numColors-1] = firstColor;
    		repaint();
    }

    /** Invert the colors in the bullseye */
    public void invert() {
    		int numColors = this.colorArray.length;
    		Color tempColor;
    		
    		for (int i = 0; i < (numColors+1)/2; i++) {
    			tempColor = this.colorArray[i];
    			this.colorArray[i] = this.colorArray[numColors-1-i];
    			this.colorArray[numColors-1-i] = tempColor;
    		}
    		
    		repaint();
    }

    /**
     *  The component will look bad if it is sized smaller than this
     *  @returns The minimum dimension
     */
    public Dimension getMinimumSize() {
    		return new Dimension(this.diameter,this.diameter);
    }

    /**
     *  The component will look best at this size
     *  @returns The preferred dimension
     */
    public Dimension getPreferredSize() {
    		return new Dimension(this.diameter,this.diameter);
    }
}
